@@ -15,6 +15,7 @@ use bytes::Bytes;
 use std::collections::HashMap;
 use std::future::Future;
 use std::pin::Pin;
+use std::sync::Arc;
 
 /// Interceptor can be used to add functionality to you PeerConnections by modifying any incoming/outgoing rtp/rtcp
 /// packets, or sending your own packets as needed.
@@ -24,23 +25,23 @@ pub trait Interceptor {
     /// change in the future. The returned method will be called once per packet batch.
     async fn bind_rtcp_reader(
         &self,
-        reader: Box<dyn RTCPReader + Send + Sync>,
-    ) -> Box<dyn RTCPReader + Send + Sync>;
+        reader: Arc<dyn RTCPReader + Send + Sync>,
+    ) -> Arc<dyn RTCPReader + Send + Sync>;
 
     /// bind_rtcp_writer lets you modify any outgoing RTCP packets. It is called once per PeerConnection. The returned method
     /// will be called once per packet batch.
     async fn bind_rtcp_writer(
         &self,
-        writer: Box<dyn RTCPWriter + Send + Sync>,
-    ) -> Box<dyn RTCPWriter + Send + Sync>;
+        writer: Arc<dyn RTCPWriter + Send + Sync>,
+    ) -> Arc<dyn RTCPWriter + Send + Sync>;
 
     /// bind_local_stream lets you modify any outgoing RTP packets. It is called once for per LocalStream. The returned method
     /// will be called once per rtp packet.
     async fn bind_local_stream(
         &self,
         info: &StreamInfo,
-        writer: Box<dyn RTPWriter + Send + Sync>,
-    ) -> Box<dyn RTPWriter + Send + Sync>;
+        writer: Arc<dyn RTPWriter + Send + Sync>,
+    ) -> Arc<dyn RTPWriter + Send + Sync>;
 
     /// unbind_local_stream is called when the Stream is removed. It can be used to clean up any data related to that track.
     async fn unbind_local_stream(&self, info: &StreamInfo);
@@ -50,8 +51,8 @@ pub trait Interceptor {
     async fn bind_remote_stream(
         &self,
         info: &StreamInfo,
-        reader: Box<dyn RTPReader + Send + Sync>,
-    ) -> Box<dyn RTPReader + Send + Sync>;
+        reader: Arc<dyn RTPReader + Send + Sync>,
+    ) -> Arc<dyn RTPReader + Send + Sync>;
 
     /// unbind_remote_stream is called when the Stream is removed. It can be used to clean up any data related to that track.
     async fn unbind_remote_stream(&self, info: &StreamInfo);
@@ -63,12 +64,7 @@ pub trait Interceptor {
 #[async_trait]
 pub trait RTPWriter {
     /// write a rtp packet
-    async fn write(
-        &self,
-        header: &rtp::header::Header,
-        payload: &Bytes,
-        attributes: &Attributes,
-    ) -> Result<usize>;
+    async fn write(&self, pkt: &rtp::packet::Packet, attributes: &Attributes) -> Result<usize>;
 }
 
 /// RTPReader is used by Interceptor.bind_remote_stream.
@@ -84,7 +80,7 @@ pub trait RTCPWriter {
     /// write a batch of rtcp packets
     async fn write(
         &self,
-        pkts: &dyn rtcp::packet::Packet,
+        pkt: &(dyn rtcp::packet::Packet + Send + Sync),
         attributes: &Attributes,
     ) -> Result<usize>;
 }
@@ -121,7 +117,7 @@ pub type RTPReaderFn = Box<
 /// RTCPWriterFn is an adapter for RTCPWriter interface
 pub type RTCPWriterFn = Box<
     dyn (FnMut(
-            &dyn rtcp::packet::Packet,
+            &(dyn rtcp::packet::Packet + Send + Sync),
             &Attributes,
         ) -> Pin<Box<dyn Future<Output = Result<usize>> + Send + 'static>>)
         + Send
